# Приведение и преобразование данных в нужный тип средствами Python, для последующей вставки в бд

Написано на версии python 3.5

## Установка
```
pip install python-data-transformer
```

## Документация
На данный момент отсутствует

## Зависимости
Отсутствуют

## Автор
Павел Максимов

Связаться со мной можно в 
[Телеграм](https://t.me/pavel_maksimow) 
и в 
[Facebook](https://www.facebook.com/pavel.maksimow)

Удачи тебе, друг! Поставь звездочку ;)

